-- Groups table with participant caching
CREATE TABLE IF NOT EXISTS groups (
  id TEXT PRIMARY KEY, -- WhatsApp group ID
  name TEXT NOT NULL DEFAULT 'Unnamed group',
  participants TEXT DEFAULT NULL, -- JSON array of phone numbers (nullable)
  linked_parent TEXT, -- Parent community ID
  last_updated TEXT -- ISO 8601 timestamp of last update
);

-- Tasks table with phone number assignments
CREATE TABLE IF NOT EXISTS tasks (
  id INTEGER PRIMARY KEY AUTOINCREMENT,
  description TEXT NOT NULL,
  created_by TEXT NOT NULL, -- WhatsApp phone number of task creator
  assigned_to TEXT NOT NULL DEFAULT '', -- WhatsApp phone number (empty string if unassigned)
  due_date TEXT, -- ISO 8601 date string (e.g., "2023-10-31")
  completed BOOLEAN NOT NULL DEFAULT FALSE,
  created_at TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
  updated_at TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP
);

-- Users table for name mapping
CREATE TABLE IF NOT EXISTS users (
  phone_number TEXT PRIMARY KEY, -- WhatsApp phone number
  name TEXT NOT NULL,
  last_seen TEXT -- ISO 8601 timestamp of last activity
);

-- User preferences table
CREATE TABLE IF NOT EXISTS user_preferences (
  phone_number TEXT PRIMARY KEY,
  reminders_enabled BOOLEAN NOT NULL DEFAULT TRUE,
  FOREIGN KEY(phone_number) REFERENCES users(phone_number)
);

-- Create triggers for task timestamps
CREATE TRIGGER IF NOT EXISTS update_task_timestamp
AFTER UPDATE ON tasks
BEGIN
  UPDATE tasks SET updated_at = CURRENT_TIMESTAMP WHERE id = NEW.id;
END;
